@@ -1,5 +1,5 @@
 /*
- * Copyright © 2007,2008 daniel g. siegel <dgsiegel@gmail.com>
+ * Copyright © 2007,2008 daniel g. siegel <dgsiegel@gnome.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -172,6 +172,21 @@ cheese_gconf_get_property (GObject *object, guint prop_id, GValue *value,
                                                          CHEESE_GCONF_PREFIX "/enable_delete",
                                                          NULL));
       break;
+    case GCONF_PROP_WIDE_MODE:
+      g_value_set_boolean (value, gconf_client_get_bool (priv->client,
+                                                         CHEESE_GCONF_PREFIX "/wide_mode",
+                                                         NULL));
+      break;
+    case GCONF_PROP_BURST_DELAY:
+      g_value_set_int (value, gconf_client_get_int (priv->client,
+                                                    CHEESE_GCONF_PREFIX "/burst_delay",
+                                                    NULL));
+      break;
+    case GCONF_PROP_BURST_REPEAT:
+      g_value_set_int (value, gconf_client_get_int (priv->client,
+                                                    CHEESE_GCONF_PREFIX "/burst_repeat",
+                                                    NULL));
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -299,6 +314,24 @@ cheese_gconf_set_property (GObject *object, guint prop_id, const GValue *value,
                              g_value_get_boolean (value),
                              NULL);
       break;
+    case GCONF_PROP_WIDE_MODE:
+      gconf_client_set_bool (priv->client,
+                             CHEESE_GCONF_PREFIX "/wide_mode",
+                             g_value_get_boolean (value),
+                             NULL);
+      break;
+    case GCONF_PROP_BURST_DELAY:
+      gconf_client_set_int (priv->client,
+                            CHEESE_GCONF_PREFIX "/burst_delay",
+                            g_value_get_int (value),
+                            NULL);
+      break;
+    case GCONF_PROP_BURST_REPEAT:
+      gconf_client_set_int (priv->client,
+                            CHEESE_GCONF_PREFIX "/burst_repeat",
+                            g_value_get_int (value),
+                            NULL);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -421,6 +454,30 @@ cheese_gconf_class_init (CheeseGConfClass *klass)
                                                          FALSE,
                                                          G_PARAM_READWRITE));
 
+  g_object_class_install_property (object_class, GCONF_PROP_WIDE_MODE,
+                                   g_param_spec_boolean ("gconf_prop_wide_mode",
+                                                         NULL,
+                                                         NULL,
+                                                         FALSE,
+                                                         G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class, GCONF_PROP_BURST_DELAY,
+                                   g_param_spec_int ("gconf_prop_burst_delay",
+                                                     NULL,
+                                                     NULL,
+                                                     200,  /* based on some experiments */
+                                                     G_MAXINT,
+                                                     1000,
+                                                     G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class, GCONF_PROP_BURST_REPEAT,
+                                   g_param_spec_int ("gconf_prop_burst_repeat",
+                                                     NULL,
+                                                     NULL,
+                                                     1,
+                                                     G_MAXINT,
+                                                     4,
+                                                     G_PARAM_READWRITE));
 
   g_type_class_add_private (klass, sizeof (CheeseGConfPrivate));
 }
