@@ -1,5 +1,5 @@
 /*
- * Copyright © 2007,2008 daniel g. siegel <dgsiegel@gmail.com>
+ * Copyright © 2007,2008 daniel g. siegel <dgsiegel@gnome.org>
  * Copyright © 2007,2008 Jaap Haitsma <jaap@haitsma.org>
  * Copyright © 2008 Patryk Zawadzki <patrys@pld-linux.org>
  * Copyright © 2008 Ryan Zeigler <zeiglerr@gmail.com>
@@ -334,16 +334,20 @@ cheese_window_toggle_wide_mode (GtkWidget *widget, CheeseWindow *cheese_window)
 
   /* set a single column in wide mode */
   gtk_icon_view_set_columns (GTK_ICON_VIEW (cheese_window->thumb_view), toggled ? 1 : G_MAXINT);
+
   /* switch thumb_nav mode */
   eog_thumb_nav_set_vertical (EOG_THUMB_NAV (cheese_window->thumb_nav), toggled);
 
   /* reparent thumb_view */
   g_object_ref (cheese_window->thumb_scrollwindow);
-  if (toggled) {
+  if (toggled)
+  {
     gtk_container_remove (GTK_CONTAINER (cheese_window->video_vbox), cheese_window->thumb_scrollwindow);
     gtk_container_add (GTK_CONTAINER (cheese_window->netbook_alignment), cheese_window->thumb_scrollwindow);
     g_object_unref (cheese_window->thumb_scrollwindow);
-  } else {
+  }
+  else
+  {
     gtk_container_remove (GTK_CONTAINER (cheese_window->netbook_alignment), cheese_window->thumb_scrollwindow);
     gtk_box_pack_end (GTK_BOX (cheese_window->video_vbox), cheese_window->thumb_scrollwindow, FALSE, FALSE, 0);
     g_object_unref (cheese_window->thumb_scrollwindow);
@@ -353,9 +357,11 @@ cheese_window_toggle_wide_mode (GtkWidget *widget, CheeseWindow *cheese_window)
   }
 
   /* update spacing */
+
   /* NOTE: be really carefull when changing the ui file to update spacing
    * values here too! */
-  if (toggled) {
+  if (toggled)
+  {
     g_object_set (G_OBJECT (cheese_window->toolbar_alignment),
                   "bottom-padding", 10, NULL);
     g_object_set (G_OBJECT (cheese_window->togglegroup_alignment),
@@ -364,7 +370,9 @@ cheese_window_toggle_wide_mode (GtkWidget *widget, CheeseWindow *cheese_window)
                   "right-padding", 0, NULL);
     g_object_set (G_OBJECT (cheese_window->netbook_alignment),
                   "left-padding", 6, NULL);
-  } else {
+  }
+  else
+  {
     g_object_set (G_OBJECT (cheese_window->toolbar_alignment),
                   "bottom-padding", 6, NULL);
     g_object_set (G_OBJECT (cheese_window->togglegroup_alignment),
@@ -462,7 +470,8 @@ static void
 cheese_window_photo_saved_cb (CheeseWebcam *webcam, CheeseWindow *cheese_window)
 {
   gdk_threads_enter ();
-  if (!cheese_window->is_bursting) {
+  if (!cheese_window->is_bursting)
+  {
     gtk_action_group_set_sensitive (cheese_window->actions_effects, TRUE);
     gtk_action_group_set_sensitive (cheese_window->actions_toggle, TRUE);
     gtk_widget_set_sensitive (cheese_window->take_picture, TRUE);
@@ -1023,17 +1032,19 @@ static void
 cheese_window_cmd_about (GtkAction *action, CheeseWindow *cheese_window)
 {
   static const char *authors[] = {
-    "daniel g. siegel <dgsiegel@gmail.com>",
+    "daniel g. siegel <dgsiegel@gnome.org>",
     "Jaap A. Haitsma <jaap@haitsma.org>",
+    "Filippo Argiolas <fargiolas@gnome.org>",
     "",
+    "Aidan Delaney <a.j.delaney@brighton.ac.uk>",
     "Alex \"weej\" Jones <alex@weej.com>",
     "Andrea Cimitan <andrea.cimitan@gmail.com>",
     "Baptiste Mille-Mathias <bmm80@free.fr>",
     "Cosimo Cecchi <anarki@lilik.it>",
     "Diego Escalante Urrelo <dieguito@gmail.com>",
     "Felix Kaser <f.kaser@gmx.net>",
-    "Filippo Argiolas <filippo.argiolas@gmail.com>",
     "Gintautas Miliauskas <gintas@akl.lt>",
+    "Hans de Goede <jwrdegoede@fedoraproject.org>",
     "James Liggett <jrliggett@cox.net>",
     "Luca Ferretti <elle.uca@libero.it>",
     "Mirco \"MacSlow\" Müller <macslow@bangang.de>",
@@ -1054,11 +1065,13 @@ cheese_window_cmd_about (GtkAction *action, CheeseWindow *cheese_window)
     "Kalle Persson <kalle@kallepersson.se>",
     "Lapo Calamandrei <calamandrei@gmail.com>",
     "Or Dvory <gnudles@nana.co.il>",
+    "Ulisse Perusin <ulisail@yahoo.it>",
     NULL
   };
 
   static const char *documenters[] = {
     "Joshua Henderson <joshhendo@gmail.com>",
+    "Jaap A. Haitsma <jaap@haitsma.org>",
     NULL
   };
 
@@ -1349,6 +1362,20 @@ cheese_window_escape_key_cb (CheeseWindow *cheese_window,
     gtk_widget_set_sensitive (cheese_window->take_picture, TRUE);
     gtk_widget_set_sensitive (cheese_window->take_picture_fullscreen, TRUE);
   }
+  else if (cheese_window->webcam_mode == WEBCAM_MODE_BURST)
+  {
+    cheese_window->repeat_count = 0;
+    cheese_window->is_bursting  = FALSE;
+
+    gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook_bar), 0);
+    gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->fullscreen_bar), 0);
+
+    gtk_action_group_set_sensitive (cheese_window->actions_effects, TRUE);
+    gtk_action_group_set_sensitive (cheese_window->actions_toggle, TRUE);
+
+    gtk_widget_set_sensitive (cheese_window->take_picture, TRUE);
+    gtk_widget_set_sensitive (cheese_window->take_picture_fullscreen, TRUE);
+  }
   else
   {
     cheese_window_stop_recording (cheese_window);
@@ -1362,6 +1389,13 @@ cheese_window_take_photo (gpointer data)
   gboolean      countdown;
   CheeseWindow *cheese_window = (CheeseWindow *) data;
 
+  /* return if burst mode was cancelled */
+  if (cheese_window->webcam_mode == WEBCAM_MODE_BURST &&
+      !cheese_window->is_bursting && cheese_window->repeat_count <= 0)
+  {
+    return FALSE;
+  }
+
   g_object_get (cheese_window->gconf, "gconf_prop_countdown", &countdown, NULL);
   if (countdown)
   {
@@ -1397,9 +1431,10 @@ cheese_window_take_photo (gpointer data)
   gtk_widget_set_sensitive (cheese_window->take_picture, FALSE);
   gtk_widget_set_sensitive (cheese_window->take_picture_fullscreen, FALSE);
 
-  if (cheese_window->webcam_mode == WEBCAM_MODE_BURST) {
-    guint repeat_delay = 1000;
-    gboolean countdown = FALSE;
+  if (cheese_window->webcam_mode == WEBCAM_MODE_BURST)
+  {
+    guint    repeat_delay = 1000;
+    gboolean countdown    = FALSE;
 
     g_object_get (cheese_window->gconf, "gconf_prop_burst_delay", &repeat_delay, NULL);
     g_object_get (cheese_window->gconf, "gconf_prop_countdown", &countdown, NULL);
@@ -1410,8 +1445,10 @@ cheese_window_take_photo (gpointer data)
        * Magic number chosen via expiriment on Netbook */
       repeat_delay = 5000;
     }
+
     /* start burst mode phot series */
-    if (!cheese_window->is_bursting) {
+    if (!cheese_window->is_bursting)
+    {
       g_timeout_add (repeat_delay, cheese_window_take_photo, cheese_window);
       cheese_window->is_bursting = TRUE;
     }
@@ -1429,45 +1466,53 @@ cheese_window_take_photo (gpointer data)
 static void
 cheese_window_action_button_clicked_cb (GtkWidget *widget, CheeseWindow *cheese_window)
 {
-  char     *str;
+  char *str;
 
-  switch (cheese_window->webcam_mode) {
-  case WEBCAM_MODE_BURST:
-    gtk_action_group_set_sensitive (cheese_window->actions_effects, FALSE);
-    gtk_action_group_set_sensitive (cheese_window->actions_toggle, FALSE);
-    g_object_get (cheese_window->gconf, "gconf_prop_burst_repeat", &cheese_window->repeat_count, NULL); /* reset burst counter */
-  case WEBCAM_MODE_PHOTO:
-    cheese_window_take_photo (cheese_window);
-    break;
-  case WEBCAM_MODE_VIDEO:
-    if (!cheese_window->recording)
-    {
+  switch (cheese_window->webcam_mode)
+  {
+    case WEBCAM_MODE_BURST:
+
+      /* ignore keybindings and other while bursting */
+      if (cheese_window->is_bursting)
+      {
+        break;
+      }
       gtk_action_group_set_sensitive (cheese_window->actions_effects, FALSE);
       gtk_action_group_set_sensitive (cheese_window->actions_toggle, FALSE);
-      str = g_strconcat ("<b>", _("_Stop Recording"), "</b>", NULL);
-      gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_take_photo), str);
-      gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_take_photo_fullscreen), str);
-      g_free (str);
-      gtk_label_set_use_markup (GTK_LABEL (cheese_window->label_take_photo), TRUE);
-      gtk_image_set_from_stock (GTK_IMAGE (cheese_window->image_take_photo), GTK_STOCK_MEDIA_STOP, GTK_ICON_SIZE_BUTTON);
-      gtk_label_set_use_markup (GTK_LABEL (cheese_window->label_take_photo_fullscreen), TRUE);
-      gtk_image_set_from_stock (GTK_IMAGE (cheese_window->image_take_photo_fullscreen),
-                                GTK_STOCK_MEDIA_STOP, GTK_ICON_SIZE_BUTTON);
+      g_object_get (cheese_window->gconf, "gconf_prop_burst_repeat", &cheese_window->repeat_count, NULL); /* reset burst counter */
+    case WEBCAM_MODE_PHOTO:
+      cheese_window_take_photo (cheese_window);
+      break;
+    case WEBCAM_MODE_VIDEO:
+      if (!cheese_window->recording)
+      {
+        gtk_action_group_set_sensitive (cheese_window->actions_effects, FALSE);
+        gtk_action_group_set_sensitive (cheese_window->actions_toggle, FALSE);
+        str = g_strconcat ("<b>", _("_Stop Recording"), "</b>", NULL);
+        gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_take_photo), str);
+        gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_take_photo_fullscreen), str);
+        g_free (str);
+        gtk_label_set_use_markup (GTK_LABEL (cheese_window->label_take_photo), TRUE);
+        gtk_image_set_from_stock (GTK_IMAGE (
+                                    cheese_window->image_take_photo), GTK_STOCK_MEDIA_STOP, GTK_ICON_SIZE_BUTTON);
+        gtk_label_set_use_markup (GTK_LABEL (cheese_window->label_take_photo_fullscreen), TRUE);
+        gtk_image_set_from_stock (GTK_IMAGE (cheese_window->image_take_photo_fullscreen),
+                                  GTK_STOCK_MEDIA_STOP, GTK_ICON_SIZE_BUTTON);
 
-      cheese_window->video_filename = cheese_fileutil_get_new_media_filename (cheese_window->fileutil,
-                                                                              WEBCAM_MODE_VIDEO);
-      cheese_webcam_start_video_recording (cheese_window->webcam, cheese_window->video_filename);
+        cheese_window->video_filename = cheese_fileutil_get_new_media_filename (cheese_window->fileutil,
+                                                                                WEBCAM_MODE_VIDEO);
+        cheese_webcam_start_video_recording (cheese_window->webcam, cheese_window->video_filename);
 
-      cheese_window->recording = TRUE;
-    }
-    else
-    {
-      cheese_window_stop_recording (cheese_window);
-    }
-    break;
-  default:
-    g_assert_not_reached ();
-    break;
+        cheese_window->recording = TRUE;
+      }
+      else
+      {
+        cheese_window_stop_recording (cheese_window);
+      }
+      break;
+    default:
+      g_assert_not_reached ();
+      break;
   }
 }
 
@@ -1589,9 +1634,9 @@ cheese_window_activate_radio_action (GtkAction *action, GtkRadioAction *current,
     gtk_label_set_use_markup (GTK_LABEL (cheese_window->label_take_photo), TRUE);
     gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_take_photo_fullscreen), g_strdup (str));
     gtk_label_set_use_markup (GTK_LABEL (cheese_window->label_take_photo_fullscreen), TRUE);
-    gtk_action_group_set_sensitive (cheese_window->actions_burst, TRUE);
-    gtk_action_group_set_sensitive (cheese_window->actions_video, FALSE);
     gtk_action_group_set_sensitive (cheese_window->actions_photo, FALSE);
+    gtk_action_group_set_sensitive (cheese_window->actions_video, FALSE);
+    gtk_action_group_set_sensitive (cheese_window->actions_burst, TRUE);
   }
   else
   {
@@ -1681,7 +1726,7 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   GError     *error = NULL;
   char       *path;
   GtkBuilder *builder;
-  GtkWidget *menubar;
+  GtkWidget  *menubar;
 
   cheese_window->info_bar = NULL;
 
@@ -2080,7 +2125,7 @@ void
 cheese_window_init (char *hal_dev_udi, CheeseDbus *dbus_server, gboolean startup_in_wide_mode)
 {
   CheeseWindow *cheese_window;
-  gboolean startup_in_wide_mode_saved;
+  gboolean      startup_in_wide_mode_saved;
 
   cheese_window = g_new0 (CheeseWindow, 1);
 
@@ -2116,7 +2161,8 @@ cheese_window_init (char *hal_dev_udi, CheeseDbus *dbus_server, gboolean startup
 
   startup_in_wide_mode = startup_in_wide_mode_saved ? TRUE : startup_in_wide_mode;
 
-  if (startup_in_wide_mode) {
+  if (startup_in_wide_mode)
+  {
     GtkAction *action = gtk_ui_manager_get_action (cheese_window->ui_manager, "/MainMenu/Cheese/WideMode");
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
   }
